
From: "Randy.Dunlap" <rddunlap@osdl.org>

This is a patch from Robert Day that does the following:

1) shift menu item in "Processor type and features" menu
2) clean up "Bus options" menu so it's actually hierarchical

Part of it (moving X86_IO_APIC around) looked a little odd to me,
so I asked Roman Zippel about it, and he replied:

"It's correct, although I wouldn't call it a 'design quirk'. :)
It forces one to group options which belong logically together and in this 
case X86_IO_APIC is really a bit misplaced, even if it's not visible."

I have tested it (on 2.5.68-plain) and it does indeed make the menus
more hierarchical ... so please apply it.



 arch/i386/Kconfig   |   58 ++++++++++++++++++++++++++--------------------------
 drivers/mca/Kconfig |    3 --
 2 files changed, 29 insertions(+), 32 deletions(-)

diff -puN arch/i386/Kconfig~config-menu-aesthetics arch/i386/Kconfig
--- 25/arch/i386/Kconfig~config-menu-aesthetics	2003-04-23 00:14:50.000000000 -0700
+++ 25-akpm/arch/i386/Kconfig	2003-04-23 00:14:50.000000000 -0700
@@ -413,6 +413,18 @@ config SMP
 
 	  If you don't know what to do here, say N.
 
+config NR_CPUS
+	int "Maximum number of CPUs (2-32)"
+	depends on SMP
+	default "32"
+	help
+	  This allows you to specify the maximum number of CPUs which this
+	  kernel will support.  The maximum supported value is 32 and the
+	  minimum value which makes sense is 2.
+
+	  This is purely to save memory - each supported CPU adds
+	  approximately eight kilobytes to the kernel image.
+
 config PREEMPT
 	bool "Preemptible Kernel"
 	help
@@ -465,18 +477,6 @@ config X86_IO_APIC
 	depends on !SMP && X86_UP_IOAPIC
 	default y
 
-config NR_CPUS
-	int "Maximum number of CPUs (2-32)"
-	depends on SMP
-	default "32"
-	help
-	  This allows you to specify the maximum number of CPUs which this
-	  kernel will support.  The maximum supported value is 32 and the
-	  minimum value which makes sense is 2.
-
-	  This is purely to save memory - each supported CPU adds
-	  approximately eight kilobytes to the kernel image.
-
 config X86_TSC
 	bool
 	depends on (MWINCHIP3D || MWINCHIP2 || MCRUSOE || MCYRIXIII || MK7 || MK6 || MPENTIUM4 || MPENTIUMIII || MPENTIUMII || M686 || M586MMX || M586TSC || MK8 || MVIAC3_2) && !X86_NUMAQ
@@ -1027,6 +1027,11 @@ config X86_LOCAL_APIC
 	depends on (X86_VISWS || SMP) && !X86_VOYAGER
 	default y
 
+config X86_IO_APIC
+	bool
+	depends on SMP && !(X86_VISWS || X86_VOYAGER)
+	default y
+
 config PCI
 	bool "PCI support" if !X86_VISWS
 	depends on !X86_VOYAGER
@@ -1042,11 +1047,6 @@ config PCI
 	  information about which PCI hardware does work under Linux and which
 	  doesn't.
 
-config X86_IO_APIC
-	bool
-	depends on SMP && !(X86_VISWS || X86_VOYAGER)
-	default y
-
 choice
 	prompt "PCI access mode"
 	depends on PCI && !X86_VISWS
@@ -1086,18 +1086,6 @@ config PCI_DIRECT
  	depends on PCI && ((PCI_GODIRECT || PCI_GOANY) || X86_VISWS)
 	default y
 
-config SCx200
-	tristate "NatSemi SCx200 support"
-	depends on !X86_VOYAGER
-	help
-	  This provides basic support for the National Semiconductor SCx200 
-	  processor.  Right now this is just a driver for the GPIO pins.
-
-	  If you don't know what to do here, say N.
-
-	  This support is also available as a module.  If compiled as a
-	  module, it will be called scx200.
-
 source "drivers/pci/Kconfig"
 
 config ISA
@@ -1143,6 +1131,18 @@ config MCA
 
 source "drivers/mca/Kconfig"
 
+config SCx200
+	tristate "NatSemi SCx200 support"
+	depends on !X86_VOYAGER
+	help
+	  This provides basic support for the National Semiconductor SCx200 
+	  processor.  Right now this is just a driver for the GPIO pins.
+
+	  If you don't know what to do here, say N.
+
+	  This support is also available as a module.  If compiled as a
+	  module, it will be called scx200.
+
 config HOTPLUG
 	bool "Support for hot-pluggable devices"
 	---help---
diff -puN drivers/mca/Kconfig~config-menu-aesthetics drivers/mca/Kconfig
--- 25/drivers/mca/Kconfig~config-menu-aesthetics	2003-04-23 00:14:50.000000000 -0700
+++ 25-akpm/drivers/mca/Kconfig	2003-04-23 00:14:50.000000000 -0700
@@ -1,6 +1,3 @@
-comment "Micro Channel Architecture Bus support"
-	depends on MCA
-
 config MCA_LEGACY
 	bool "Legacy MCA API Support"
 	depends on MCA

_
